==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/StandardRoleEmbeddedTargetsCatalog.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CatalogApplication;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * App targets
 */
@ApiModel(description = "App targets")
@JsonPropertyOrder({ StandardRoleEmbeddedTargetsCatalog.JSON_PROPERTY_APPS })
@JsonTypeName("StandardRole__embedded_targets_catalog")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class StandardRoleEmbeddedTargetsCatalog implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_APPS = "apps";
    private List<CatalogApplication> apps = null;

    public StandardRoleEmbeddedTargetsCatalog() {
    }

    public StandardRoleEmbeddedTargetsCatalog apps(List<CatalogApplication> apps) {

        this.apps = apps;
        return this;
    }

    public StandardRoleEmbeddedTargetsCatalog addappsItem(CatalogApplication appsItem) {
        if (this.apps == null) {
            this.apps = new ArrayList<>();
        }
        this.apps.add(appsItem);
        return this;
    }

    /**
     * Get apps
     *
     * @return apps
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<CatalogApplication> getApps() {
        return apps;
    }

    @JsonProperty(JSON_PROPERTY_APPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setApps(List<CatalogApplication> apps) {
        this.apps = apps;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        StandardRoleEmbeddedTargetsCatalog standardRoleEmbeddedTargetsCatalog = (StandardRoleEmbeddedTargetsCatalog) o;
        return Objects.equals(this.apps, standardRoleEmbeddedTargetsCatalog.apps);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(apps);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class StandardRoleEmbeddedTargetsCatalog {\n");
        sb.append("    apps: ").append(toIndentedString(apps)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/StandardRoleEmbeddedTargetsCatalog.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CatalogApplication;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * App targets
 */
@ApiModel(description = "App targets")
@JsonPropertyOrder({ StandardRoleEmbeddedTargetsCatalog.JSON_PROPERTY_APPS })
@JsonTypeName("StandardRole__embedded_targets_catalog")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class StandardRoleEmbeddedTargetsCatalog implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_APPS = "apps";
    private List<CatalogApplication> apps = null;

    public StandardRoleEmbeddedTargetsCatalog() {
    }

    public StandardRoleEmbeddedTargetsCatalog apps(List<CatalogApplication> apps) {

        this.apps = apps;
        return this;
    }

    public StandardRoleEmbeddedTargetsCatalog addappsItem(CatalogApplication appsItem) {
        if (this.apps == null) {
            this.apps = new ArrayList<>();
        }
        this.apps.add(appsItem);
        return this;
    }

    /**
     * Get apps
     *
     * @return apps
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<CatalogApplication> getApps() {
        return apps;
    }

    @JsonProperty(JSON_PROPERTY_APPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setApps(List<CatalogApplication> apps) {
        this.apps = apps;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        StandardRoleEmbeddedTargetsCatalog standardRoleEmbeddedTargetsCatalog = (StandardRoleEmbeddedTargetsCatalog) o;
        return Objects.equals(this.apps, standardRoleEmbeddedTargetsCatalog.apps);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(apps);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class StandardRoleEmbeddedTargetsCatalog {\n");
        sb.append("    apps: ").append(toIndentedString(apps)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
